@@ -87,7 +87,7 @@ PHPUnit_Util_Filter::addFileToFilter(__FILE__, 'PHPUNIT');
  * @author     Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @copyright  2002-2010 Sebastian Bergmann <sb@sebastian-bergmann.de>
  * @license    http://www.opensource.org/licenses/bsd-license.php  BSD License
- * @version    Release: 3.4.13
+ * @version    Release: 3.4.14
  * @link       http://www.phpunit.de/
  * @since      Class available since Release 2.0.0
  */
@@ -512,11 +512,32 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
 
             // TestCase($name, $data)
             else {
-                $data   = PHPUnit_Util_Test::getProvidedData($className, $name);
+                try {
+                    $data = PHPUnit_Util_Test::getProvidedData(
+                      $className, $name
+                    );
+                }
+
+                catch (Exception $e) {
+                    $message = sprintf(
+                      'The data provider specified for %s::%s is invalid.',
+                      $className,
+                      $name
+                    );
+
+                    $_message = $e->getMessage();
+
+                    if (!empty($_message)) {
+                        $message .= "\n" . $_message;
+                    }
+
+                    return new PHPUnit_Framework_Warning($message);
+                }
+
                 $groups = PHPUnit_Util_Test::getGroups($className, $name);
 
                 // Test method with @dataProvider.
-                if (is_array($data) || $data instanceof Iterator) {
+                if (isset($data)) {
                     $test = new PHPUnit_Framework_TestSuite_DataProvider(
                       $className . '::' . $name
                     );
@@ -548,17 +569,6 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
                     }
                 }
 
-                // Test method with invalid @dataProvider.
-                else if ($data === FALSE) {
-                    $test = new PHPUnit_Framework_Warning(
-                      sprintf(
-                        'The data provider specified for %s::%s is invalid.',
-                        $className,
-                        $name
-                      )
-                    );
-                }
-
                 else {
                     $test = new $className;
                 }
@@ -944,4 +954,4 @@ class PHPUnit_Framework_TestSuite implements PHPUnit_Framework_Test, PHPUnit_Fra
     {
     }
 }
-?>
+?>
\ No newline at end of file
